searchData={"items":[{"type":"module","title":"StableJason","doc":"Encoder of Elixir values to a stable JSON.","ref":"StableJason.html"},{"type":"function","title":"StableJason.encode/2","doc":"Generates stable JSON corresponding to `input`.\n\n`opts` are the same as `Jason.encode/2`.","ref":"StableJason.html#encode/2"},{"type":"function","title":"Example - StableJason.encode/2","doc":"iex> StableJason.encode(%{c: 3, b: 2, a: 1})\n    {:ok, ~S|{\"a\":1,\"b\":2,\"c\":3}|}\n\n    iex> StableJason.encode(<<0::1>>)\n    {:error,\n      %Protocol.UndefinedError{\n        protocol: Jason.Encoder,\n        value: <<0::size(1)>>,\n        description: \"cannot encode a bitstring to JSON\"\n      }}","ref":"StableJason.html#encode/2-example"},{"type":"function","title":"StableJason.encode!/2","doc":"Generates stable JSON corresponding to `input`.\n\nSimilar to `encode/2` except it will unwrap the error tuple and raise\nin case of errors.","ref":"StableJason.html#encode!/2"},{"type":"function","title":"Examples - StableJason.encode!/2","doc":"iex> StableJason.encode!(%{a: 1})\n    ~S|{\"a\":1}|\n\n    iex> StableJason.encode!(\"\\xFF\")\n    ** (Jason.EncodeError) invalid byte 0xFF in <<255>>","ref":"StableJason.html#encode!/2-examples"},{"type":"module","title":"StableJason.Encoder","doc":"Utilities for encoding Elixir values to a deterministic or stable JSON.","ref":"StableJason.Encoder.html"},{"type":"function","title":"StableJason.Encoder.encode/1","doc":"Generates stable JSON corresponding to `input` using `%Jason.OrderedObject{}` from `Jason`.","ref":"StableJason.Encoder.html#encode/1"},{"type":"function","title":"Example - StableJason.Encoder.encode/1","doc":"iex> StableJason.Encoder.encode(%{c: 3, b: 2, a: 1})\n    {:ok, %Jason.OrderedObject{values: [{\"a\", 1}, {\"b\", 2}, {\"c\", 3}]}}\n\n    iex> StableJason.Encoder.encode(<<0::1>>)\n    {:error,\n      %Protocol.UndefinedError{\n        protocol: Jason.Encoder,\n        value: <<0::size(1)>>,\n        description: \"cannot encode a bitstring to JSON\"\n      }}","ref":"StableJason.Encoder.html#encode/1-example"},{"type":"extras","title":"StableJason","doc":"# StableJason\n\n[Online Documentation](https://hexdocs.pm/stable_jason).\n\n`StableJason` is a library for encoding Elixir values to a stable JSON with deterministic sorting for keys.\n\nIt works similar like [OJSON](https://hex.pm/packages/ojson) but can output a pretty JSON string, using [Jason](https://hex.pm/packages/jason) as the underlying JSON encoder.\n\n The initial use-case for this library is to display a diff between two JSON files, where the order of keys is not important. The problem with JSON is that the order of keys is not guaranteed, so a diff between two JSON files can be very noisy. By using `StableJason` to encode the JSON files, the order of keys is deterministic, so the diff will be much more readable.","ref":"readme.html"},{"type":"extras","title":"Examples - StableJason","doc":"```elixir\nStableJason.encode(%{c: 3, b: 2, a: 1})\n{:ok, ~S|{\"a\":1,\"b\":2,\"c\":3}|}\n\nStableJason.encode(%{c: 3, b: 2, a: 1}, pretty: true)\n{:ok, \"{\\n  \\\"a\\\": 1,\\n  \\\"b\\\": 2,\\n  \\\"c\\\": 3\\n}\"}\n\nStableJason.encode!(%{c: 3, b: 2, a: 1})\n\"{\\\"a\\\":1,\\\"b\\\":2,\\\"c\\\":3}\"\n\nStableJason.encode!(%{c: 3, b: 2, a: 1}, pretty: true)\n\"{\\n  \\\"a\\\": 1,\\n  \\\"b\\\": 2,\\n  \\\"c\\\": 3\\n}\"\n```","ref":"readme.html#examples"},{"type":"extras","title":"Installation - StableJason","doc":"Add `stable_jason` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:stable_jason, \"~> 0.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - StableJason","doc":"StableJason is released under the Apache License 2.0 - see the [LICENSE](LICENSE) file.","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.0.1 - 2024-01-18 - Changelog","doc":"* Initial release","ref":"changelog.html#0-0-1-2024-01-18"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2024-present Aleksandr Lossenko\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"}],"content_type":"text/markdown"}